#!/bin/bash

# PARAMS: mesh1 nPoints outputDir
if [ `uname -n` == "c2.cs.princeton.edu" ]; then 
	runJobsAs="qsubEach"
else
	runJobsAs="execOneByOne"
fi

if [ $# -lt 3 ]; then
	echo "Usage: "
	echo "	./FindPoints.sh meshName nPoints outputDir"
	echo ""
	exit
fi


   # change some parameters. You can change more in settings.txt
   # num samples - to approximate confidence and similarity
numSamples=$2
	# work folder
workDir=$3

############ YOU SHOULD NOT NEED TO EDIT ANYTHING BELOW THIS LINE #######################
	# by default eigendecomposition of the sparse blended matrix is used via MATLAB
	# (ran as external command). If you don't have MATLAB installed - 
	# set useMatlab=false and SVDLIBC will be used instead.
scriptDir=`dirname $0`
if [ ! -d $workDir ]; then
	mkdir $workDir
fi

if [ ! -d $workDir ]; then
	echo Could not find work directory: $workDir
	exit
fi

	# read file names as arguments - or use default
mesh1=$1

	# separate file name and extension - to create workspace directory
if [ ! -f $mesh1 ]; then
	echo File $mesh1 does not exist!
fi;

fileonly1=`basename $mesh1`
ext="."`echo "$fileonly1" | cut -d'.' -f2`
mesh1name=`echo "$fileonly1" | cut -d'.' -f1`
	
	# create workspace directory, copy files
if [ ! -d $workDir/$mesh1name ]; then
	mkdir $workDir/$mesh1name
fi

if [ ! -f $workDir/$mesh1name/$mesh1name$ext ]; then
	cp $mesh1 $workDir/$mesh1name
fi

	# NOTE: arguments to SurfaceVis below OVERWRITE settings.txt file
	# I included them here for simplicity - so that one would not have to modify settings.txt
	
	# Set input files (copied to their work directories)
params="-ConfSurfaces MeshName [$mesh1name $mesh1name] MeshExt $ext"
	# Set number of samples on surface
params="$params -SamplesFine_EVEN MaxSamples $numSamples MaxIterations $numSamples"
	# Set whether to open visualization
params="$params -Pipeline Visualize false"
	# Set workDir
params="$params -Pipeline WorkFolder $workDir"

if [ runJobsAs == "qsubEach" ]; then
	if [ ! -d FindPntsScript ]; then
		mkdir FindPntsScript
	fi
	scriptName=FindPntsScript/$mesh1name.qsub
	echo "#!/bin/bash" > $scriptName.sh
	echo "$scriptDir/`uname`_`uname -m`_SurfaceVis $scriptDir/settingsPoints.txt $params" >> $scriptName.sh
	qsubParams="-l mem=4000mb,cput=8:00:00 -N $fileonly1 -d `pwd` -o $scriptName.log -e $scriptName.err" 
	IDstr=`qsub $qsubParams $scriptName.sh`
	ID=`echo "$IDstr" | cut -d'.' -f1`
	echo "$ID" >> qSubProcs.txt
else
	$scriptDir/`uname`_`uname -m`_SurfaceVis $scriptDir/settingsPoints.txt $params
fi
