#!/bin/bash
# !/bin/sh

# PARAMETERS
# upvector
upVec="[0 0 1]"
#upVec="none"


# sequential execution
runJobsAs="execOneByOne"
# parallel execution (needs multi-node cluster, uses qsub:
#	http://www.clusterresources.com/torquedocs21/commands/qsub.shtml
#runJobsAs="qsubEach"



##### DO NOT MODIFY THINGS BELOW #####
monitorAll="true"

#upVec="none"
#matlabPath="/Applications/MATLAB_R2010a.app/bin/"
#matlabPath="/Applications/MATLAB_R2008a/bin/"
matlabPath="/usr/local/matlab/bin/"
PATH="$PATH:$matlabPath"
export PATH

if [ $# -lt 1 ]; then
    echo "Usage: "
    echo "	./AnalyzeDB dbName [optional: nPoints] [optional: supplementalDB]"
    echo ""
    exit
fi

dbName=$1

echo "[NOTE] Up Vector="$upVec

params="-LoadDatabase INPUT_DataDirs none OUTPUT_DBDir "$1""
params="$params -Pipeline ExternalMonitor $monitorAll"

benchmark="false"

if [ $# -ge 2 ]; then
	params=$params" -LoadDatabase INPUT_MinNVertices "$2" -LoadPointSet INPUT_NPoints "$2
fi

# load additional database (e.g. humans to put on chairs in 
# 'functional labeling' app (see future work of Fuzzy Corrs. paper)
if [ $# -ge 3 ]; then
	params=$params" -Pipeline +Load LoadSupportDB"
	params=$params" -LoadSupportDB INPUT_DataDirs none"
	params=$params" -LoadSupportDB INPUT_DataFiles database.txt"
	params=$params" -LoadSupportDB OUTPUT_DBDir $3"
	params=$params" -LoadSupportDB INPUT_MinNVertices $2"
fi

params=$params" -ExplorePCACorrs INPUT_UpVector $upVec"

# executing on cluster, can use qsub
if [ $runJobsAs == "qsubEach" ]; then
	if [ ! -d TempScripts ]; then
		mkdir TempScripts
	fi
	scriptName=TempScripts/$1.sh
	errName=TempScripts/$1.err
	logName=TempScripts/$1.log
	echo "#!/bin/bash" > $scriptName
	echo "./DatabaseVis settings.txt $params" >> $scriptName
	qsubParams="-l mem=8000mb,cput=48:00:00 -N $1 -d `pwd` -o $logName -e $errName" 
	IDserv=`qsub $qsubParams $scriptName`
	ID=`echo "$IDserv" | cut -d'.' -f1`
	if [ $monitorAll == "true" ]; then
		echo "Monitoring qsubbed job $ID $dbName"
		nohup ./MonitorGeneral.sh $dbName $ID > $dbName/MonitoringGeneral.log &
	fi	
	#nohup ./MonitorLSFuzzyBatch.sh $ID $dbName &
else
# executing on a single machine
	./`uname`_`uname -m`_DatabaseVis settings.txt $params &

	if [ $monitorAll == "true" ]; then
		currPid=$!
		echo "Monitoring everything: "$dbName" pID="$currPid
		./MonitorGeneral.sh $dbName $currPid &
	fi
fi


