#!/bin/bash

#PARAMETERS
# sequential execution
runJobsAs="execOneByOne"
# parallel execution (needs multi-node cluster, uses qsub:
#	http://www.clusterresources.com/torquedocs21/commands/qsub.shtml
#runJobsAs="qsubEach"


##### DO NOT MODIFY BELOW ####
if [ $# -lt 1 ]; then
	echo "Usage: "
	echo "	./AnalyzeDB_BIM dbName [optional: nPoints] [optional: supplementalDB]"
	echo ""
	exit
fi

matlabPath="/usr/local/matlab/bin/"
PATH="$PATH:$matlabPath"
export PATH

monitorAll="true"
#./RecompileAll.sh

dbName=$1
nPoints=128
bimMaxDist=.3

if [ $# -ge 2 ]; then
	nPoints=$2
fi



# params: database
params="-LoadDatabase INPUT_DataDirs none OUTPUT_DBDir "$dbName

# params: read external points
params=$params" -LoadDatabase INPUT_MinNVertices "0
params=$params" -LoadPointSet PointSetType External"
params=$params" -LoadPointSet INPUT_NPoints "$nPoints
params=$params" -LoadPointSet INPUT_PntsDir "$dbName/BIM/
f="_OriginalFilename_"
params=$params" -LoadPointSet INPUT_PntsFile $f/Blended_$f.smplset.even"

# params: intrinsic maps
params=$params" -LoadDynamicGraphCorrs INPUT_PairwiseCollModule ExploreBIMCorrs"
params=$params" -LoadDynamicGraphCorrs INPUT_PairwiseCorrValModule LoadBIMCorrValues"
params=$params" -LoadDynamicGraphCorrs INPUT_ExploreParallel true"
params=$params" -LoadDynamicGraphCorrs INPUT_KeepConnected true"
params=$params" -LoadDynamicGraphCorrs INPUT_IterPruneEdges 0"
params=$params" -ExploreBIMCorrs INPUT_MaxDist $bimMaxDist"


params=$params" -Pipeline +Load LoadGeodesicDistance"

query="none"
if [ "$dbName" == "BIM_Animals" ]; then
	query="../../../Data/CorrsBenchmark/Results/Corr_Animals.query"
fi

if [ "$dbName" == "BIM_Animals2" ] || [ "$dbName" == "BIM_Animals5" ] || [ "$dbName" == "BIM_Animals8" ] || [ "$dbName" == "BIM_Animals11" ] || [ "$dbName" == "BIM_Animals14" ] || [ "$dbName" == "BIM_Animals17" ] || [ "$dbName" == "BIM_Animals20" ]; then
	query="../../../Data/CorrsBenchmark/Results/Corr_AnimalsSize.query"
fi

if [ "$dbName" == "BIM_Scape" ] || [ "$dbName" == "BIM_Scape_pts32" ] || [ "$dbName" == "BIM_Scape_pts64" ] || [ "$dbName" == "BIM_Scape_pts128" ] || [ "$dbName" == "BIM_Scape_pts256" ] || [ "$dbName" == "BIM_Scape_pts512" ] || [ "$dbName" == "BIM_Scape_pts1024" ]; then
	query="../../../Data/CorrsBenchmark/Results/Corr_Scape.query"
fi

if [ "$dbName" == "BIM_Humans" ]; then
	query="../../../Data/CorrsBenchmark/Results/Corr_Humans.query"
fi

if [ "$dbName" == "SHRECDB_Animals" ]; then
	query="../../../Data/CorrsBenchmark/Results/Corr_SHREC_Animals.query"
fi

if [ "$dbName" == "SHRECDB_Humans" ]; then
	query="../../../Data/CorrsBenchmark/Results/Corr_SHREC_Humans.query"
fi

if [ "$dbName" == "SHRECDB_Teddies" ]; then
	query="../../../Data/CorrsBenchmark/Results/Corr_SHREC_Teddy.query"
fi

if [ "$dbName" == "SHRECDB_Hands" ]; then
	query="../../../Data/CorrsBenchmark/Results/Corr_SHREC_Hand.query"
fi

# add collection
if [ "$dbName" == "SHRECDB_Hands" ]; then 
	params=$params" -Pipeline +Load [LoadNguyenCorrs] "
	params=$params" -LoadNguyenCorrs Type CorrCollectionLoader"
	params=$params" -LoadNguyenCorrs CollectionType CollectionPairwise"
	params=$params" -LoadNguyenCorrs CorrsType NguyenVtxMap INPUT_Dir PrintedMaps"
	params=$params" -LoadNguyenCorrs MEMORY_CorrCollName NguyenMap"	
	params=$params" -LoadNguyenCorrs INPUT_ModelsSelection AllPairs"
	params=$params" -LoadNguyenCorrs INPUT_ConcatenateIntoSingleFile true"

#params=$params" -LoadNguyenVals Type CorrValueLoader CorrValueType default"
#params=$params" -LoadNguyenVals MEMORY_Name	NguyenVals"
fi

# add query
if [ $query != "none" ]; then
	echo Using Query: $query
	params=$params" -Pipeline +Load [CreateDiffuseInterpolator LoadCorrValInterpDiff]"
	params=$params" -Pipeline +Load CorrBenchmarkApp"

	params=$params" -CreateDiffuseInterpolator INPUT_ToPnts AllVertices"

	params=$params" -CorrBenchmarkApp INPUT_QueryFile $query"
	params=$params" -CorrBenchmarkApp INPUT_ModelPairs InputQueryFile"
	params=$params" -CorrBenchmarkApp INPUT_TakeBestCorr true"
	params=$params" -CorrBenchmarkApp INPUT_WriteFuzzyPair true"
	params=$params" -CorrBenchmarkApp INPUT_WriteCoarsePair true"
	params=$params" -CorrBenchmarkApp INPUT_WriteFinePair true"
	params=$params" -CorrBenchmarkApp INPUT_WriteErrors false"
fi


# params: read supplemental database
if [ $# -ge 3 ]; then
	params=$params" -LoadSupportDB INPUT_DataDirs none INPUT_DataFiles database.txt"
	params=$params" OUTPUT_DBDir "$3
	params=$params" -LoadSupportDB INPUT_MinNVertices "$nPoints
fi

params=$params" -Pipeline ExternalMonitor $monitorAll"


echo "NPoints=$nPoints sigma=$bimMaxDist"

if [ $runJobsAs == "qsubEach" ]; then
	tempScriptsDir="./TempScripts/"
	if [ ! -d $tempScriptsDir ]; then
		mkdir $tempScriptsDir
	fi
	prefix=$tempScriptsDir/$dbName.qsub
	outLog=$prefix.log
	outErr=$prefix.err
	scriptName=$prefix.sh

	echo "" > qSubProcs.txt
	python ../BIM/UseBIMToFindPoints.py $dbName $nPoints
	cp qSubProcs.txt $dbName
	./TerminateWhenDone.sh $dbName/qSubProcs.txt

	echo "#!/bin/bash" > $scriptName
#	echo "python ../BIM/UseBIMToFindPoints.py $dbName $nPoints" >> $scriptName
	echo "./DatabaseVis settings.txt $params" >> $scriptName
	qsubParams="-l mem=8000mb,cput=8:00:00 -N $dbName -d `pwd` -o $outLog -e $outErr" 
	IDserv=`qsub $qsubParams $scriptName`
	ID=`echo "$IDserv" | cut -d'.' -f1`
	echo "Monitoring qsubbed job $ID $dbName"
	nohup ./MonitorBIMBatch.sh $ID $dbName $bimMaxDist &
	if [ $monitorAll == "true" ]; then
		echo "Also monitor everything"
		nohup ./MonitorGeneral.sh $dbName $ID > $dbName/MonitoringGeneral.log &
	fi	
else
	python ../BIM/UseBIMToFindPoints.py $dbName $nPoints
	./`uname`_`uname -m`_DatabaseVis settings.txt $params &
	if [ $monitorAll == "true" ]; then
		currPid=$!
		echo "Monitoring everything (BIM): "$dbName" pID="$currPid
		./MonitorGeneral.sh $dbName $currPid &
		./MonitorBIMBatch.sh $currPid $dbName $bimMaxDist $runJobsAs &
	fi
fi

