#!/bin/bash

if [ `uname -n` == "c2.cs.princeton.edu" ]; then 
	runJobsAs="qsubEach"
	matExe="/usr/local/matlab/bin/matlab"
else
	runJobsAs="execOneByOne"
	matExe="matlab"
fi

if [ $# -lt 1 ]; then
	echo "Usage: "
	echo "	./MonitorGeneral.sh dbName [optional processID]"
	echo ""
	exit
fi

monitorDir=./$1/MonitorScripts/
qsubDir=./$1/MonitorScripts/QSubDir/

ID="none"
if [ $# -eq 2 ]; then
	ID=$2	
fi

sleepTime=5
maxTime=28800

while [ $maxTime -ge 0 ]; do
	sleep $sleepTime"s"
	let maxTime=$maxTime-$sleepTime
	if [ ! "$ID" == "none" ]; then
		if [ $runJobsAs == "qsubEach" ]; then
			nIDs=`qstat $ID | grep -c vk`
		else
			nIDs=`ps -p $ID | grep -c $ID`
		fi
	else
		nIDs=1
	fi

	if [ $nIDs -eq 0 ]; then
		break;
	fi
	
	if [ -f $monitorDir/*.sh ]; then
	for scriptName in `ls -f $monitorDir/*.sh`; do
		sleep $sleepTime"s"
		chmod 777 $scriptName
		if [ ! -d $qsubDir ]; then
			mkdir $qsubDir
		fi
		nameOnly=`basename $scriptName`
		mv $scriptName $qsubDir/$nameOnly

		scriptName=$qsubDir/$nameOnly

		if [ $runJobsAs == "qsubEach" ]; then
			qsubParams="-l mem=4000mb,cput=8:00:00 -N $nameOnly"
			qsubParams="$qsubParams -d `pwd` -o $scriptName.log -e $scriptName.err" 
			qsub $qsubParams $scriptName
		else
			echo "RUN: "$scriptName
			$scriptName & 
		fi
	done
	fi
done

echo "Terminated Monitoring: $1"

